@@ -35,6 +35,10 @@ import _hashlib  # type: ignore  # noqa
 import py7zr.win32compat
 
 
+# String used at the beginning of relative paths
+RELATIVE_PATH_MARKER = "./"
+
+
 def calculate_crc32(data: bytes, value: int = 0, blocksize: int = 1024 * 1024) -> int:
     """Calculate CRC32 of strings with arbitrary lengths."""
     if len(data) <= blocksize:
@@ -416,3 +420,15 @@ class Buffer:
 
     def __bytes__(self):
         return bytes(self._buf[0 : self._buflen])
+
+
+def remove_relative_path_marker(path: str) -> str:
+    """
+    Removes './' from the beginning of a path-like string
+    """
+    processed_path = path
+
+    if path.startswith(RELATIVE_PATH_MARKER):
+        processed_path = path[len(RELATIVE_PATH_MARKER) :]
+
+    return processed_path
