@@ -45,7 +45,15 @@ from py7zr.archiveinfo import Folder, Header, SignatureHeader
 from py7zr.callbacks import ExtractCallback
 from py7zr.compressor import SupportedMethods, get_methods_names
 from py7zr.exceptions import Bad7zFile, CrcError, DecompressionError, InternalError, UnsupportedCompressionMethodError
-from py7zr.helpers import ArchiveTimestamp, MemIO, NullIO, calculate_crc32, filetime_to_dt, readlink
+from py7zr.helpers import (
+    ArchiveTimestamp,
+    MemIO,
+    NullIO,
+    calculate_crc32,
+    filetime_to_dt,
+    readlink,
+    remove_relative_path_marker,
+)
 from py7zr.properties import DEFAULT_FILTERS, FILTER_DEFLATE64, MAGIC_7Z, get_default_blocksize, get_memory_limit
 from py7zr.win32compat import is_windows_native_python, is_windows_unc_path
 
@@ -563,15 +571,15 @@ class SevenZipFile(contextlib.AbstractContextManager):
             if path is None:
                 # do following but is_relative_to introduced in py 3.9
                 # so I replaced it with relative_to. when condition is not satisfied, raise ValueError
-                # if not pathlib.Path(...).joinpath(outname.lstrip("./")).is_relative_to(...):
+                # if not pathlib.Path(...).joinpath(remove_relative_path_marker(outname)).is_relative_to(...):
                 #    raise Bad7zFile
                 try:
-                    pathlib.Path(os.getcwd()).joinpath(outname.lstrip("./")).relative_to(os.getcwd())
+                    pathlib.Path(os.getcwd()).joinpath(remove_relative_path_marker(outname)).relative_to(os.getcwd())
                 except ValueError:
                     raise Bad7zFile
-                outfilename = pathlib.Path(outname.lstrip("./"))
+                outfilename = pathlib.Path(remove_relative_path_marker(outname))
             else:
-                outfilename = path.joinpath(outname.lstrip("./"))
+                outfilename = path.joinpath(remove_relative_path_marker(outname))
                 try:
                     outfilename.relative_to(path)
                 except ValueError:
@@ -969,7 +977,7 @@ class SevenZipFile(contextlib.AbstractContextManager):
     def extractall(self, path: Optional[Any] = None, callback: Optional[ExtractCallback] = None) -> None:
         """Extract all members from the archive to the current working
         directory and set owner, modification time and permissions on
-        directories afterwards. `path' specifies a different directory
+        directories afterwards. ``path`` specifies a different directory
         to extract to.
         """
         self._extract(path=path, return_dict=False, callback=callback)
@@ -1015,19 +1023,18 @@ class SevenZipFile(contextlib.AbstractContextManager):
             raise ValueError("specified path is not a directory or a file")
 
     def write(self, file: Union[pathlib.Path, str], arcname: Optional[str] = None):
-        """Write single target file into archive(Not implemented yet)."""
+        """Write single target file into archive."""
         if isinstance(file, str):
             path = pathlib.Path(file)
         elif isinstance(file, pathlib.Path):
             path = file
         else:
             raise ValueError("Unsupported file type.")
-        self.header.initialize()
+        folder = self.header.initialize()
         file_info = self._make_file_info(path, arcname, self.dereference)
         self.header.files_info.files.append(file_info)
         self.header.files_info.emptyfiles.append(file_info["emptystream"])
         self.files.append(file_info)
-        folder = self.header.main_streams.unpackinfo.folders[-1]
         self.worker.archive(self.fp, self.files, folder, deref=self.dereference)
 
     def writed(self, targets: Dict[str, IO[Any]]) -> None:
@@ -1051,12 +1058,11 @@ class SevenZipFile(contextlib.AbstractContextManager):
         else:
             raise ValueError("Wrong argument passed for argument bio.")
         if size > 0:
-            self.header.initialize()
+            folder = self.header.initialize()
             file_info = self._make_file_info_from_name(bio, size, arcname)
             self.header.files_info.files.append(file_info)
             self.header.files_info.emptyfiles.append(file_info["emptystream"])
             self.files.append(file_info)
-            folder = self.header.main_streams.unpackinfo.folders[-1]
             self.worker.archive(self.fp, self.files, folder, deref=False)
         else:
             file_info = self._make_file_info_from_name(bio, size, arcname)
@@ -1093,7 +1099,9 @@ class SevenZipFile(contextlib.AbstractContextManager):
         self._var_release()
 
     def reset(self) -> None:
-        """When read mode, it reset file pointer, decompress worker and decompressor"""
+        """
+        When read mode, it reset file pointer, decompress worker and decompressor
+        """
         if self.mode == "r":
             self.fp.seek(self.afterheader)
             self.worker = Worker(self.files, self.afterheader, self.header, self.mp)
@@ -1159,14 +1167,18 @@ def is_7zfile(file: Union[BinaryIO, str, pathlib.Path]) -> bool:
 
 
 def unpack_7zarchive(archive, path, extra=None):
-    """Function for registering with shutil.register_unpack_format()"""
+    """
+    Function for registering with shutil.register_unpack_format().
+    """
     arc = SevenZipFile(archive)
     arc.extractall(path)
     arc.close()
 
 
 def pack_7zarchive(base_name, base_dir, owner=None, group=None, dry_run=None, logger=None):
-    """Function for registering with shutil.register_archive_format()"""
+    """
+    Function for registering with shutil.register_archive_format().
+    """
     target_name = "{}.7z".format(base_name)
     with SevenZipFile(target_name, mode="w") as archive:
         archive.writeall(path=base_dir)
@@ -1174,7 +1186,9 @@ def pack_7zarchive(base_name, base_dir, owner=None, group=None, dry_run=None, lo
 
 
 class Worker:
-    """Extract worker class to invoke handler"""
+    """
+    Extract worker class to invoke handler.
+    """
 
     def __init__(self, files, src_start: int, header, mp=False) -> None:
         self.target_filepath: Dict[int, Union[MemIO, pathlib.Path, None]] = {}
@@ -1266,7 +1280,9 @@ class Worker:
         exc_q: Optional[queue.Queue] = None,
         skip_notarget=True,
     ) -> None:
-        """Single thread extractor that takes file lists in single 7zip folder."""
+        """
+        Single thread extractor that takes file lists in single 7zip folder.
+        """
         if files is None:
             return
         try:
@@ -1351,7 +1367,9 @@ class Worker:
             self._check(fp, just_check, src_end)
 
     def _check(self, fp, check_target, src_end):
-        # delayed execution of crc check.
+        """
+        delayed execution of crc check.
+        """
         for f in check_target:
             with NullIO() as ofp:
                 crc32 = self.decompress(fp, f.folder, ofp, f.uncompressed, f.compressed, src_end)
@@ -1367,7 +1385,8 @@ class Worker:
         compressed_size: Optional[int],
         src_end: int,
     ) -> int:
-        """decompressor wrapper called from extract method.
+        """
+        decompressor wrapper called from extract method.
 
         :parameter fp: archive source file pointer
         :parameter folder: Folder object that have decompressor object.
@@ -1375,7 +1394,9 @@ class Worker:
         :parameter size: uncompressed size of target file.
         :parameter compressed_size: compressed size of target file.
         :parameter src_end: end position of the folder
+
         :returns None
+
         """
         assert folder is not None
         out_remaining = size
@@ -1396,7 +1417,9 @@ class Worker:
         return crc32
 
     def _find_link_target(self, target):
-        """Find the target member of a symlink or hardlink member in the archive."""
+        """
+        Find the target member of a symlink or hardlink member in the archive.
+        """
         targetname: str = target.as_posix()
         linkname = readlink(targetname)
         # Check windows full path symlinks
@@ -1455,8 +1478,9 @@ class Worker:
                 self.header.files_info.files[self.last_file_index]["maxsize"] = foutsize
         # Update size data in header
         self.header.main_streams.packinfo.numstreams += 1
-        self.header.main_streams.packinfo.crcs.append(compressor.digest)
-        self.header.main_streams.packinfo.digestdefined.append(True)
+        if self.header.main_streams.packinfo.enable_digests:
+            self.header.main_streams.packinfo.crcs.append(compressor.digest)
+            self.header.main_streams.packinfo.digestdefined.append(True)
         self.header.main_streams.packinfo.packsizes.append(compressor.packsize)
         folder.unpacksizes = compressor.unpacksizes
 
